@@ -6,7 +6,7 @@ use Regexp::Grammars;
 use Moo;
 use namespace::autoclean;
 
-our $VERSION = '0.006';    # VERSION
+our $VERSION = '0.007';    # VERSION
 
 # ABSTRACT: Parse DOS .bat and .cmd files
 
@@ -19,11 +19,11 @@ has 'grammar' => (
     
            <rule: File> (?:<[Lines]>\n)*
 
-           <rule: Lines> <Comment> | <Label> | <Statement>
+           <rule: Lines> <Comment> | <Label> | <Statement> 
 
            <rule: Comment> \:\:<Text=Token> | REM <Text=Token>
 
-           <rule: Label> \:(?!:)<Identifier=Token>
+           <rule: Label> \:(?!:)<Identifier=LabelIdentifier>[^\n]*
 
            <rule: Statement> \@?<Command>
            
@@ -47,7 +47,7 @@ has 'grammar' => (
 
            <rule: Call> call <Token>
 
-           <rule: Goto> Goto <Identifier=Token>
+           <rule: Goto> Goto <Identifier=LabelIdentifier>
 
            <rule: Set> set <Variable=Token>=<Value=Token>
 
@@ -61,6 +61,8 @@ has 'grammar' => (
 
            <token: Token> [^\n]*
 
+           <token: LabelIdentifier> [^\n\s]*
+
         }xmi;
     }
 );
@@ -104,7 +106,7 @@ App::BatParser - Parse DOS .bat and .cmd files
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 DESCRIPTION
 
@@ -148,7 +150,7 @@ the same terms as the Perl 5 programming language system itself.
 
 =head1 CONTRIBUTORS
 
-=for stopwords eva.dominguez Toby Inkster
+=for stopwords eva.dominguez juanradiego Toby Inkster
 
 =over 4
 
@@ -158,6 +160,10 @@ eva.dominguez <eva.dominguez@meteologica.com>
 
 =item *
 
+juanradiego <kilaweo@gmail.com>
+
+=item *
+
 Toby Inkster <tobyink@cpan.org>
 
 =back
